#!/bin/sh

# SPDX-FileCopyrightText: OpenTalk GmbH <mail@opentalk.eu>
#
# SPDX-License-Identifier: EUPL-1.2

ACTIVE_FEATURES="{
    userSearch: ${FEATURE_USER_SEARCH:-true},
    muteUsers: ${FEATURE_MUTE_USER:-true},
    resetHandraises: ${FEATURE_RESET_HANDRAISES:-true},
    breakoutRooms: ${FEATURE_BREAKOUT_ROOMS:-true},
    poll: ${FEATURE_POLL:-true},
    vote: ${FEATURE_VOTE:-true},
    autoModeration: ${FEATURE_AUTO_MODERATION:-false},
    protocol: ${FEATURE_PROTOCOL:-false},
    timer: ${FEATURE_TIMER:-false},
    coffeeBreak: ${FEATURE_COFFEE_BREAK:-false},
    addUser: ${FEATURE_ADD_USER:-false},
    talkingStick: ${FEATURE_TALKING_STICK:-false},
    wheelOfNames: ${FEATURE_WHEEL_OF_NAMES:-false},
    joinWithoutMedia: ${FEATURE_JOIN_WITHOUT_MEDIA:-false},
    whiteboard: ${FEATURE_WHITEBOARD:-false},
    recording: ${FEATURE_RECORDING:-false},
}"

DEFAULT_VIDEO_BACKGROUNDS='[]'

# Deprecated fallback for $KEYCLOAK_AUTHORITY
if [[ x"${KEYCLOAK_AUTHORITY}" != "x" ]]; then
    OIDC_ISSUER=$KEYCLOAK_AUTHORITY
fi

cat >/usr/share/nginx/html/config.js << EOF
window.config = {
  controller: "${CONTROLLER_HOST}",
  insecure: ${INSECURE:-false},
  baseUrl: "${BASE_URL}",
  helpdeskUrl: "${HELPDESK_URL}",
  errorReportAddress: "${ERROR_REPORT_ADDRESS}",
  beta: {
    isBeta: ${IS_BETA_RELEASE:-true},
    badgeUrl: "${BETA_BADGE_URL}"
  },
  libravatarDefaultImage: "${LIBRAVATAR_DEFAULT_IMAGE:-robohash}",
  oidcConfig: {
    authority: "${OIDC_ISSUER}",
    clientId: "${OIDC_CLIENT_ID:-Frontend}",
    scope: "openid profile email",
    redirectPath: "/auth/callback",
    signOutRedirectUri: "${SIGN_OUT_REDIRECT_URI:-/dashboard}",
    popupRedirectPath: "/auth/popup_callback",
  },
  changePassword: {
    active: ${CHANGE_PASSWORD_ACTIVE:-false},
    url: "${CHANGE_PASSWORD_URL}",
  },
  userSurveyUrl: "${USER_SURVEY_URL}",
  userSurveyApiKey: "${USER_SURVEY_API_KEY}",
  speedTest: {
    ndtServer: "${NDT_SERVER}",
    ndtDownloadWorkerJs: "/workers/ndt7-download-worker.js",
    ndtUploadWorkerJs: "/workers/ndt7-upload-worker.js",
  },
  features: ${ACTIVE_FEATURES},
  videoBackgrounds: ${VIDEO_BACKGROUNDS:-${DEFAULT_VIDEO_BACKGROUNDS}},
  maxVideoBandwidth: ${MAX_VIDEO_BANDWIDTH:-600000}
}
EOF
